@@ -14,10 +14,10 @@ from scrapy.exceptions import NotConfigured
 from scrapy.utils.boto import is_botocore
 from six.moves.urllib.parse import urlparse, unquote
 from twisted.internet import defer, threads
+import logging
+
 
 class WarcioMiddleware:
-
-
     @classmethod
     def from_crawler(cls, crawler):
         o = cls(crawler.settings, crawler.stats)
@@ -29,49 +29,57 @@ class WarcioMiddleware:
         pass
 
     def spider_closed(self, spider):
-        job_dir = self.settings['JOBDIR'] or ''
-        s3_dir = self.settings['S3DIR'] or ''
-        self.storage.store()
+        job_dir = self.settings["JOBDIR"] or ""
+        s3_dir = self.settings["S3DIR"] or ""
+        import os
 
+        for root, dirs, files in os.walk(".", topdown=False):
+            for name in files:
+                self.log.info(name)
+                if ".warc.gz" in name:
+                    with open(os.path.join(root, name)) as f:
+                        self.storage.store(name, f)
 
-    def __init__(self, settings,stats):
+    def __init__(self, settings, stats):
         self.warcio = ScrapyWarcIo(settings)
         self.stats = stats
         self.settings = settings
-        job_dir = self.settings['JOBDIR'] or ''
-        s3_dir = self.settings['S3DIR'] or ''
-
-        self.storage = S3Storage(s3_dir)
+        self.job_dir = self.settings["JOBDIR"] or ""
+        self.s3_dir = self.settings["S3DIR"] or ""
+        self.storage = S3Storage(self.s3_dir)
+        self.log = logging.getLogger(__name__)
 
     def process_request(self, request, spider):
-        request.meta['WARC-Date'] = warc_date()
+        request.meta["WARC-Date"] = warc_date()
         return None
 
     def process_response(self, request, response, spider):
         self.warcio.write(response, request)
         return response
 
-class S3Storage():
 
+class S3Storage:
     def __init__(self, uri, access_key=None, secret_key=None, acl=None):
         # BEGIN Backward compatibility for initialising without keys (and
         # without using from_crawler)
         no_defaults = access_key is None and secret_key is None
         if no_defaults:
             from scrapy.utils.project import get_project_settings
+
             settings = get_project_settings()
-            if 'AWS_ACCESS_KEY_ID' in settings or 'AWS_SECRET_ACCESS_KEY' in settings:
+            if "AWS_ACCESS_KEY_ID" in settings or "AWS_SECRET_ACCESS_KEY" in settings:
                 import warnings
                 from scrapy.exceptions import ScrapyDeprecationWarning
+
                 warnings.warn(
                     "Initialising `scrapy.extensions.feedexport.S3FeedStorage` "
                     "without AWS keys is deprecated. Please supply credentials or "
                     "use the `from_crawler()` constructor.",
                     category=ScrapyDeprecationWarning,
-                    stacklevel=2
+                    stacklevel=2,
                 )
-                access_key = settings['AWS_ACCESS_KEY_ID']
-                secret_key = settings['AWS_SECRET_ACCESS_KEY']
+                access_key = settings["AWS_ACCESS_KEY_ID"]
+                secret_key = settings["AWS_SECRET_ACCESS_KEY"]
         # END Backward compatibility
         u = urlparse(uri)
         self.bucketname = u.hostname
@@ -81,38 +89,41 @@ class S3Storage():
         self.acl = acl
         if self.is_botocore:
             import botocore.session
+
             session = botocore.session.get_session()
             self.s3_client = session.create_client(
-                's3', aws_access_key_id=self.access_key,
-                aws_secret_access_key=self.secret_key)
+                "s3",
+                aws_access_key_id=self.access_key,
+                aws_secret_access_key=self.secret_key,
+            )
         else:
             import boto
+
             self.connect_s3 = boto.connect_s3
 
     @classmethod
     def from_crawler(cls, crawler, uri):
         return cls(
             uri=uri,
-            access_key=crawler.settings['AWS_ACCESS_KEY_ID'],
-            secret_key=crawler.settings['AWS_SECRET_ACCESS_KEY'],
-            acl=crawler.settings['FEED_STORAGE_S3_ACL'] or None
+            access_key=crawler.settings["AWS_ACCESS_KEY_ID"],
+            secret_key=crawler.settings["AWS_SECRET_ACCESS_KEY"],
+            acl=crawler.settings["FEED_STORAGE_S3_ACL"] or None,
         )
 
+    def store(self, keyname, file):
+        return threads.deferToThread(self._store, keyname, file)
 
-    def store(self,keyname, file):
-        return threads.deferToThread(self._store, keyname,file)
-
-    def _store(self,keyname, file):
+    def _store(self, keyname, file):
         file.seek(0)
         if self.is_botocore:
-            kwargs = {'ACL': self.acl} if self.acl else {}
+            kwargs = {"ACL": self.acl} if self.acl else {}
             self.s3_client.put_object(
-                Bucket=self.bucketname, Key=keyname, Body=file,
-                **kwargs)
+                Bucket=self.bucketname, Key=keyname, Body=file, **kwargs
+            )
         else:
             conn = self.connect_s3(self.access_key, self.secret_key)
             bucket = conn.get_bucket(self.bucketname, validate=False)
             key = bucket.new_key(self.keyname)
-            kwargs = {'policy': self.acl} if self.acl else {}
+            kwargs = {"policy": self.acl} if self.acl else {}
             key.set_contents_from_file(file, **kwargs)
-            key.close()
\ No newline at end of file
+            key.close()
